eric6/Globals/__init__.py

changeset 7907
7991ea245c20
parent 7861
3d48094ba8e1
child 7923
91e843545d9a
--- a/eric6/Globals/__init__.py	Mon Dec 21 13:36:24 2020 +0100
+++ b/eric6/Globals/__init__.py	Tue Dec 22 19:59:29 2020 +0100
@@ -282,11 +282,14 @@
     path = ""
     
     # step 1: check, if the user has configured a tools path
-    path = Preferences.getQt("PyQtToolsDir")
+    if version == 5:
+        path = Preferences.getQt("PyQtToolsDir")
+    elif version == 6:
+        path = Preferences.getQt("PyQt6ToolsDir")
     
     # step 2: determine from used Python interpreter (pyrcc is test object)
     if not path:
-        program = "pyrcc{0}".format(version)
+        program = "pylupdate{0}".format(version)
         if isWindowsPlatform():
             program += ".exe"
             dirName = os.path.dirname(sys.executable)
@@ -282,11 +282,14 @@
     
-    # step 2: determine from used Python interpreter (pyrcc is test object)
+    # step 2: determine from used Python interpreter (pylupdate is test object)
     if not path:

eric ide

mercurial